import 'dart:convert';

import 'package:devicelocale/devicelocale.dart';
import 'package:flutter/material.dart';
import 'package:language_builder/src/language_model.dart';
import 'package:language_builder/src/local_database.dart';
import 'package:language_builder/src/restart_app.dart';

// ignore: must_be_immutable
class LanguageBuilder extends StatefulWidget {
  /// The root widget of your app
  late Widget child;

  /// Splash screen while loading language, (at most of the time language loading is too fast)
  late Widget splash;

  ///Default language of your app
  late String defaultLanguage;

  /// This is the current language of your app
  static String? _currentLang;

  ///All texts in the application are kept in this map relative to the pages in the application.
  static Map<String, dynamic>? texts;

  ///Texts by languages
  ///key : lang code, value : texts
  static Map<String, String>? _languages;

  ///This map contains whole language json string and must be initialized at the beginning.
  late Map<String, String> textsMap;

  ///static instance of Language Builder to reach some of it's properties
  static LanguageBuilder lb = LanguageBuilder.x();

  /// If this option is true, then application's
  /// language will be set to device's selected language.
  late bool useDeviceLanguage;

  LanguageBuilder.x({Key? key}) : super(key: key);

  LanguageBuilder({
    Key? key,
    required this.child,
    this.splash = const SizedBox.shrink(),
    required this.defaultLanguage,
    this.useDeviceLanguage = false,
    required this.textsMap,
  }) : super(key: key) {
    LanguageBuilder._languages = textsMap;
  }

  static changeLanguage(String lang, BuildContext context) async {
    await DatabaseOps.db.updateLang(lang);
    LanguageBuilder.lb._setLang(lang);
    RestartApp.restartApp(context);
  }

  _setLang(String lang) {
    LanguageBuilder._currentLang = lang;
    String _jsonStr = _languages![lang]!;
    LanguageBuilder.texts = json.decode(_jsonStr);
  }

  static getCurrentLang() {
    return LanguageBuilder._currentLang;
  }

  //this method gives language by the language code.
  static getLangByCode(String code) {}

  static List<String> getAvailableLanguages() {
    return _languages!.keys.toList();
  }

  @override
  State<StatefulWidget> createState() {
    return _LanguageBuilderState();
  }
}

class _LanguageBuilderState extends State<LanguageBuilder> {
  @override
  Widget build(BuildContext context) {
    if (widget.useDeviceLanguage) {
      return FutureBuilder(
        future: Devicelocale.preferredLanguages,
        builder: (BuildContext context, AsyncSnapshot snapshot) {
          if (snapshot.hasData) {
            List languages = snapshot.data;
            String _lang;
            //get device's currently preffered language, then set it for app.
            //if there is no config for that lang, the default is 'en'
            if (languages[0].toString().contains('-')) {
              //for iOS devices it is seperated by "-"
              _lang = languages[0].toString().split('-')[0];
            } else if (languages[0].toString().contains('_')) {
              //for android devices it is seperated by "_"
              _lang = languages[0].toString().split('_')[0];
            } else {
              _lang = widget.defaultLanguage;
            }
            widget._setLang(_lang);
            return widget.child;
          } else {
            return widget.splash;
          }
        },
      );
    } else {
      DatabaseOps.defaultLang = widget.defaultLanguage;
      return FutureBuilder(
        future: DatabaseOps.db.getLang(),
        builder: (BuildContext context, AsyncSnapshot snapshot) {
          if (snapshot.hasData) {
            Language _language = snapshot.data;
            var _lang = _language.lang;
            widget._setLang(_lang);
            return RestartApp(
              child: widget.child,
            );
          } else {
            return widget.splash;
          }
        },
      );
    }
  }
}
